package com.muyu.rule.scan;

import com.muyu.rule.load.JavaBinaryClassLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.io.FilenameFilter;


/**
 * @ClassName JavaCodeScan
 * @Description 扫描文件器
 * @Author Chen
 * @Date 2024/8/23 09:56
 */
public class JavaCodeScan {
    private static final Logger log = LoggerFactory.getLogger(JavaBinaryClassLoader.class);

    private static final String JAVA_SOURCE_SUF = ".java";
    private static final String JAVA_BINARY_SUF = ".class";

    /**
     * 扫描本路径下java所有源文件 并创建为file文件
     *
     * @param filePath 文件路径
     * @return
     */

    public static File[] javaSourceScanByPath(String filePath) {

        return filterFileBySuf(filePath, JAVA_SOURCE_SUF);
    }

    /**
     * 扫描本路径下java所有源文件 并创建为file文件
     *
     * @param filePath 文件路径
     * @return
     */
    public static File[] javaBinaryByPath(String filePath) {

        return filterFileBySuf(filePath, JAVA_BINARY_SUF);
    }

    /**
     * 校验是否为java文件 是 返回File 否 抛出异常
     *
     * @param filePath
     * @return
     */
    public static File isJavaSourceScanByPath(String filePath) {
        File file = new File(filePath);
        if (file.isFile()) {
            return file;
        }
        return null;
    }

    /**
     * @param filePath 文件路径
     * @param suf      扫描后缀
     * @return
     */
    public static File[] filterFileBySuf(String filePath, String suf) {
        //创建需要扫描的文件夹
        File file = new File(filePath);
        //列出所有的筛选suf结尾的文件集
        File[] childFiles = file.listFiles(new FilenameFilter() {
            @Override
            public boolean accept(File dir, String name) {
                if (name.indexOf(suf) <= -1) {
                    return false;
                } else {
                    log.info("扫描到{}文件->{}", suf, name);
                    return true;
                }

            }
        });

        return childFiles;
    }

}
