package com.muyu.rule.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.enums.SysRuleYesNo;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.rule.mapper.RuleEditionMapper;
import com.muyu.rule.service.RuleEditionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import rule.util.GenerateConstant;
import rule.domain.Rule;
import rule.domain.RuleEdition;
import rule.util.RuleTest;

import java.util.List;

/**
 * @ClassName RuleEditionServiceImpl
 * @Description 描述
 * @Author Chen
 * @Date 2024/8/25 09:42
 */
@Service
public class RuleEditionServiceImpl extends ServiceImpl<RuleEditionMapper, RuleEdition> implements RuleEditionService {
    @Autowired
    private RuleServiceImpl ruleServiceImpl;
//    @Autowired
//    private RuleService ruleService;;

    /**
     * 禁用规则版本
     *
     * @param id
     */
    @Override
    public void disable(Long id) {
        this.settingStatus(id, SysRuleYesNo.NO.getCode());
    }


    /**
     * 启用规则版本
     *
     * @param id
     */
    @Override
    public void enable(Long id) {
        this.settingStatus(id, SysRuleYesNo.YES.getCode());
    }

    /**
     * 生成规则版本类
     *
     * @param ruleEdition
     * @return
     */
    @Override
    public RuleEdition generate(RuleEdition ruleEdition) {
        Rule rule = ruleServiceImpl.getById(ruleEdition.getRuleId());
        ruleEdition.setRuleKind(rule.getName()  + ruleEdition.getRuleCoding());
        ruleEdition.setRuleEngine(GenerateConstant.generateConstant(rule,ruleEdition));
        return ruleEdition;
    }

    /**
     * 测试规则
     * @param ruleEdition
     * @return
     */
    @Override
    public Result<String> measurementList(RuleEdition ruleEdition) {
        log.error("错误原因:{}"+ruleEdition);
        //测试
        RuleTest.test(ruleEdition);
        return Result.success("成功");
    }


    /**
     * 通过id设置
     *
     * @param id
     * @param ruleActivate
     */
    private void settingStatus(Long id, String ruleActivate) {
        LambdaQueryWrapper<RuleEdition> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(RuleEdition::getId, id);
        boolean exists = this.exists(queryWrapper);
        if (!exists) {
            throw new ServiceException("不存在");
        }
        if (!SysRuleYesNo.isCode(ruleActivate)) {
            throw new ServiceException("设置违法");
        }

        LambdaUpdateWrapper<RuleEdition> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(RuleEdition::getId, id);
        updateWrapper.set(RuleEdition::getRuleActivate, ruleActivate);
        this.update(updateWrapper);
    }
}
