package com.muyu.rule.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.utils.rule.Desensitization;
import com.muyu.rule.mapper.RuleMapper;
import com.muyu.rule.service.RuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import rule.domain.Rule;

import java.util.List;

/**
 * @ClassName RuleServiceImpl
 * @Description 规则脱敏业务实现层
 * @Author Chen
 * @Date 2024/8/20 14:19
 */
@Service
public class RuleServiceImpl extends ServiceImpl<RuleMapper, Rule> implements RuleService {

    @Override
    public List<Rule> select(Rule rule) {
        LambdaQueryWrapper<Rule> ruleLambdaQueryWrapper = new LambdaQueryWrapper<>();
        //获取到数据
        ruleLambdaQueryWrapper.select(Rule::getRuleType, Rule::getId, Rule::getRuleDesc, Rule::getIsActivate, Rule::getName);
        List<Rule> list = this.list(ruleLambdaQueryWrapper);
        //遍历
        list.forEach(rule1 -> {
                    //给手机号脱敏
                    rule1.setRuleDesc(Desensitization.mobilePhoneDesensitization(rule1.getRuleDesc()));
                }
        );
        return list;
    }

    /**
     * 基本查询
     *
     * @param rule
     * @return
     */
    @Override
    public List<Rule> selects(Rule rule) {
        LambdaQueryWrapper<Rule> ruleLambdaQueryWrapper = new LambdaQueryWrapper<>();
        //名称模糊
        if (StringUtils.isNotBlank(rule.getName())) {
            ruleLambdaQueryWrapper.like(Rule::getName, rule.getName());
        }

        //激活状态
        if (StringUtils.isNotBlank(rule.getIsActivate())) {
            ruleLambdaQueryWrapper.eq(Rule::getIsActivate, rule.getIsActivate());
        }
        List<Rule> list = this.list(ruleLambdaQueryWrapper);
        return list;
    }
}
